@@ -1,5 +1,6 @@
 import json
 
+import pandas as pd
 from dict2xml import dict2xml
 from string_utils.validation import is_integer, is_decimal
 
@@ -13,12 +14,14 @@ def format_output(obj, output_format):
         return dict2xml(obj, wrap='author')
     elif output_format == 'xml-pretty':
         return dict2xml(obj, wrap='author', indent='    ')
+    elif output_format == 'dataframe':
+        return pd.DataFrame.from_dict(obj)
     else:
         return obj
 
 
 def cast(string: str):
-    if string is None:
+    if not string:
         return None
 
     string = string.strip()
@@ -27,11 +30,11 @@ def cast(string: str):
         return int(string)
     elif is_decimal(string):
         return float(string)
-    elif string == '-':
+    elif string == '-' or string == '':
         return None
     else:
         return string
 
 
-def listify(param):
+def listify(param) -> list:
     return [param] if type(param) not in [list, tuple] else param
